Kotev
~~~~~

All this does right now is convert Hebrew text from the Assyrian alphabet to the Phonencian alphabet.


Installation
~~~~~~~~~~~~

:: 

    pip install kotev


Usage
~~~~~

::

    kotev to_phoenician 'אם אין אני לי מי לי וכשאני לעצמי מה אני ואם לא עכשיו אימתי' 

Outputs 𐤀𐤌 𐤀𐤉𐤍 𐤀𐤍𐤉 𐤋𐤉 𐤌𐤉 𐤋𐤉 𐤅𐤊𐤔𐤀𐤍𐤉 𐤋𐤏𐤑𐤌𐤉 𐤌𐤄 𐤀𐤍𐤉 𐤅𐤀𐤌 𐤋𐤀 𐤏𐤊𐤔𐤉𐤅 𐤀𐤉𐤌𐤕𐤉
